Trove Library Specific Commandments
-------------------------------------

- [T103] Exception messages should be translated
- [T105] Validate no LOG translations
- [T106] LOG.warn() is not allowed. Use LOG.warning()
